Documentation
¶
Overview ¶
Package locales provides pre-configured error message formatters for different languages. To use a locale, pass its factory function to gozod.SetConfig().
Example:
gozod.SetConfig(locales.ZhCN()) // Switch to Chinese messages globally. gozod.SetConfig(locales.EN()) // Switch back to English.
Index ¶
- Variables
- func Ar() *core.ZodConfig
- func AvailableLocales() []string
- func Bg() *core.ZodConfig
- func Cs() *core.ZodConfig
- func Da() *core.ZodConfig
- func De() *core.ZodConfig
- func EN() *core.ZodConfig
- func Es() *core.ZodConfig
- func Fa() *core.ZodConfig
- func Fi() *core.ZodConfig
- func FilterUniqueLocales(locales []string) ([]string, error)
- func FormatMessageAr(issue core.ZodRawIssue) string
- func FormatMessageBg(issue core.ZodRawIssue) string
- func FormatMessageCs(issue core.ZodRawIssue) string
- func FormatMessageDa(issue core.ZodRawIssue) string
- func FormatMessageDe(issue core.ZodRawIssue) string
- func FormatMessageEn(issue core.ZodRawIssue) string
- func FormatMessageEs(issue core.ZodRawIssue) string
- func FormatMessageFa(issue core.ZodRawIssue) string
- func FormatMessageFi(issue core.ZodRawIssue) string
- func FormatMessageFr(issue core.ZodRawIssue) string
- func FormatMessageHe(issue core.ZodRawIssue) string
- func FormatMessageHu(issue core.ZodRawIssue) string
- func FormatMessageID(issue core.ZodRawIssue) string
- func FormatMessageIt(issue core.ZodRawIssue) string
- func FormatMessageJa(issue core.ZodRawIssue) string
- func FormatMessageKo(issue core.ZodRawIssue) string
- func FormatMessageMs(issue core.ZodRawIssue) string
- func FormatMessageNl(issue core.ZodRawIssue) string
- func FormatMessageNo(issue core.ZodRawIssue) string
- func FormatMessagePl(issue core.ZodRawIssue) string
- func FormatMessagePt(issue core.ZodRawIssue) string
- func FormatMessageRu(issue core.ZodRawIssue) string
- func FormatMessageSv(issue core.ZodRawIssue) string
- func FormatMessageTa(issue core.ZodRawIssue) string
- func FormatMessageTh(issue core.ZodRawIssue) string
- func FormatMessageTr(issue core.ZodRawIssue) string
- func FormatMessageUk(issue core.ZodRawIssue) string
- func FormatMessageUr(issue core.ZodRawIssue) string
- func FormatMessageVi(issue core.ZodRawIssue) string
- func FormatMessageZh(issue core.ZodRawIssue) string
- func FormatMessageZhTw(issue core.ZodRawIssue) string
- func Fr() *core.ZodConfig
- func He() *core.ZodConfig
- func Hu() *core.ZodConfig
- func ID() *core.ZodConfig
- func It() *core.ZodConfig
- func Ja() *core.ZodConfig
- func JoinLocalizedMessages(issues []core.ZodRawIssue, locale string, separator string) (string, error)
- func Ko() *core.ZodConfig
- func LocaleFormatter(locale string) func(core.ZodRawIssue) string
- func LocalizedError(issue core.ZodRawIssue, locale string) string
- func LocalizedErrors(issues []core.ZodRawIssue, locale string) ([]string, error)
- func Ms() *core.ZodConfig
- func Nl() *core.ZodConfig
- func No() *core.ZodConfig
- func Pl() *core.ZodConfig
- func Pt() *core.ZodConfig
- func RegisterLocale(locale string, formatFunc func(core.ZodRawIssue) string)
- func Ru() *core.ZodConfig
- func Sv() *core.ZodConfig
- func Ta() *core.ZodConfig
- func Th() *core.ZodConfig
- func Tr() *core.ZodConfig
- func Uk() *core.ZodConfig
- func Ur() *core.ZodConfig
- func ValidateLocaleList(locales []string) (valid []string, invalid []string, err error)
- func Vi() *core.ZodConfig
- func ZhCN() *core.ZodConfig
- func ZhTw() *core.ZodConfig
- type LocaleErrorMap
- type RussianSizable
Constants ¶
This section is empty.
Variables ¶
var DefaultLocales = LocaleErrorMap{
"en": formatEn,
"zh-CN": formatZhCN,
"zh-TW": formatZhTw,
"zh": formatZhCN,
"de": formatDe,
"fr": formatFr,
"es": formatEs,
"it": formatIt,
"pt": formatPt,
"nl": formatNl,
"pl": formatPl,
"ru": formatRu,
"uk": formatUk,
"cs": formatCs,
"da": formatDa,
"sv": formatSv,
"tr": formatTr,
"hu": formatHu,
"fi": formatFi,
"no": formatNo,
"bg": formatBg,
"ja": formatJa,
"ko": formatKo,
"vi": formatVi,
"th": formatTh,
"id": formatID,
"ms": formatMs,
"ta": formatTa,
"ar": formatAr,
"fa": formatFa,
"he": formatHe,
"ur": formatUr,
}
DefaultLocales contains the default supported locales using functional approach Supports both full locale codes (zh-CN) and short codes (zh, en) Following TypeScript Zod v4's pattern of mapping locales to formatter functions
var FormatGenderBg = map[string]string{
"emoji": "Невалидно",
"datetime": "Невалидно",
"date": "Невалидна",
"time": "Невалидно",
"duration": "Невалидна",
}
FormatGenderBg maps Bulgarian gender adjectives for format validation.
var FormatNounsAr = map[string]string{
"regex": "مدخل",
"email": "بريد إلكتروني",
"url": "رابط",
"emoji": "إيموجي",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "تاريخ ووقت بمعيار ISO",
"date": "تاريخ بمعيار ISO",
"time": "وقت بمعيار ISO",
"duration": "مدة بمعيار ISO",
"ipv4": "عنوان IPv4",
"ipv6": "عنوان IPv6",
"mac": "عنوان MAC",
"cidrv4": "مدى عناوين بصيغة IPv4",
"cidrv6": "مدى عناوين بصيغة IPv6",
"base64": "نَص بترميز base64",
"base64url": "نَص بترميز base64url",
"json_string": "نَص على هيئة JSON",
"e164": "رقم هاتف بمعيار E.164",
"jwt": "JWT",
"template_literal": "مدخل",
}
FormatNounsAr maps Arabic format noun translations.
var FormatNounsBg = map[string]string{
"regex": "вход",
"email": "имейл адрес",
"url": "URL",
"emoji": "емоджи",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "ISO време",
"date": "ISO дата",
"time": "ISO време",
"duration": "ISO продължителност",
"ipv4": "IPv4 адрес",
"ipv6": "IPv6 адрес",
"mac": "MAC адрес",
"cidrv4": "IPv4 диапазон",
"cidrv6": "IPv6 диапазон",
"base64": "base64-кодиран низ",
"base64url": "base64url-кодиран низ",
"json_string": "JSON низ",
"e164": "E.164 номер",
"jwt": "JWT",
"template_literal": "вход",
}
FormatNounsBg maps Bulgarian format noun translations with gender.
var FormatNounsCs = map[string]string{
"regex": "regulární výraz",
"email": "e-mailová adresa",
"url": "URL",
"emoji": "emoji",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "datum a čas ve formátu ISO",
"date": "datum ve formátu ISO",
"time": "čas ve formátu ISO",
"duration": "doba trvání ISO",
"ipv4": "IPv4 adresa",
"ipv6": "IPv6 adresa",
"mac": "MAC adresa",
"cidrv4": "rozsah IPv4",
"cidrv6": "rozsah IPv6",
"base64": "řetězec zakódovaný ve formátu base64",
"base64url": "řetězec zakódovaný ve formátu base64url",
"json_string": "řetězec ve formátu JSON",
"e164": "číslo E.164",
"jwt": "JWT",
"template_literal": "vstup",
}
FormatNounsCs maps Czech format noun translations.
var FormatNounsDa = map[string]string{
"regex": "input",
"email": "e-mailadresse",
"url": "URL",
"emoji": "emoji",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "ISO dato- og klokkeslæt",
"date": "ISO-dato",
"time": "ISO-klokkeslæt",
"duration": "ISO-varighed",
"ipv4": "IPv4-adresse",
"ipv6": "IPv6-adresse",
"mac": "MAC-adresse",
"cidrv4": "IPv4-spektrum",
"cidrv6": "IPv6-spektrum",
"base64": "base64-kodet streng",
"base64url": "base64url-kodet streng",
"json_string": "JSON-streng",
"e164": "E.164-nummer",
"jwt": "JWT",
"template_literal": "input",
}
FormatNounsDa maps Danish format noun translations.
var FormatNounsDe = map[string]string{
"regex": "Eingabe",
"email": "E-Mail-Adresse",
"url": "URL",
"emoji": "Emoji",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "ISO-Datum und -Uhrzeit",
"date": "ISO-Datum",
"time": "ISO-Uhrzeit",
"duration": "ISO-Dauer",
"ipv4": "IPv4-Adresse",
"ipv6": "IPv6-Adresse",
"mac": "MAC-Adresse",
"cidrv4": "IPv4-Bereich",
"cidrv6": "IPv6-Bereich",
"base64": "Base64-codierter String",
"base64url": "Base64-URL-codierter String",
"json_string": "JSON-String",
"e164": "E.164-Nummer",
"jwt": "JWT",
"template_literal": "Eingabe",
}
FormatNounsDe maps German format noun translations.
var FormatNounsEs = map[string]string{
"regex": "entrada",
"email": "dirección de correo electrónico",
"url": "URL",
"emoji": "emoji",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "fecha y hora ISO",
"date": "fecha ISO",
"time": "hora ISO",
"duration": "duración ISO",
"ipv4": "dirección IPv4",
"ipv6": "dirección IPv6",
"mac": "dirección MAC",
"cidrv4": "rango IPv4",
"cidrv6": "rango IPv6",
"base64": "cadena codificada en base64",
"base64url": "URL codificada en base64",
"json_string": "cadena JSON",
"e164": "número E.164",
"jwt": "JWT",
"template_literal": "entrada",
}
FormatNounsEs maps Spanish format noun translations.
var FormatNounsFa = map[string]string{
"regex": "ورودی",
"email": "آدرس ایمیل",
"url": "URL",
"emoji": "ایموجی",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "تاریخ و زمان ایزو",
"date": "تاریخ ایزو",
"time": "زمان ایزو",
"duration": "مدت زمان ایزو",
"ipv4": "آدرس IPv4",
"ipv6": "آدرس IPv6",
"mac": "آدرس MAC",
"cidrv4": "دامنه IPv4",
"cidrv6": "دامنه IPv6",
"base64": "رشته base64",
"base64url": "رشته base64url",
"json_string": "رشته JSON",
"e164": "عدد E.164",
"jwt": "JWT",
"template_literal": "ورودی",
}
Persian format noun mappings
var FormatNounsFi = map[string]string{
"regex": "säännöllinen lauseke",
"email": "sähköpostiosoite",
"url": "URL-osoite",
"emoji": "emoji",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "ISO-aikaleima",
"date": "ISO-päivämäärä",
"time": "ISO-aika",
"duration": "ISO-kesto",
"ipv4": "IPv4-osoite",
"ipv6": "IPv6-osoite",
"mac": "MAC-osoite",
"cidrv4": "IPv4-alue",
"cidrv6": "IPv6-alue",
"base64": "base64-koodattu merkkijono",
"base64url": "base64url-koodattu merkkijono",
"json_string": "JSON-merkkijono",
"e164": "E.164-luku",
"jwt": "JWT",
"template_literal": "templaattimerkkijono",
}
FormatNounsFi maps Finnish format noun translations.
var FormatNounsFr = map[string]string{
"regex": "entrée",
"email": "adresse e-mail",
"url": "URL",
"emoji": "emoji",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "date et heure ISO",
"date": "date ISO",
"time": "heure ISO",
"duration": "durée ISO",
"ipv4": "adresse IPv4",
"ipv6": "adresse IPv6",
"mac": "adresse MAC",
"cidrv4": "plage IPv4",
"cidrv6": "plage IPv6",
"base64": "chaîne encodée en base64",
"base64url": "chaîne encodée en base64url",
"json_string": "chaîne JSON",
"e164": "numéro E.164",
"jwt": "JWT",
"template_literal": "entrée",
}
FormatNounsFr maps French format noun translations.
var FormatNounsHe = map[string]hebrewTypeInfo{
"regex": {Label: "קלט", Gender: "m"},
"email": {Label: "כתובת אימייל", Gender: "f"},
"url": {Label: "כתובת רשת", Gender: "f"},
"emoji": {Label: "אימוג'י", Gender: "m"},
"uuid": {Label: "UUID", Gender: "m"},
"uuidv4": {Label: "UUIDv4", Gender: "m"},
"uuidv6": {Label: "UUIDv6", Gender: "m"},
"nanoid": {Label: "nanoid", Gender: "m"},
"guid": {Label: "GUID", Gender: "m"},
"cuid": {Label: "cuid", Gender: "m"},
"cuid2": {Label: "cuid2", Gender: "m"},
"ulid": {Label: "ULID", Gender: "m"},
"xid": {Label: "XID", Gender: "m"},
"ksuid": {Label: "KSUID", Gender: "m"},
"datetime": {Label: "תאריך וזמן ISO", Gender: "m"},
"date": {Label: "תאריך ISO", Gender: "m"},
"time": {Label: "זמן ISO", Gender: "m"},
"duration": {Label: "משך זמן ISO", Gender: "m"},
"ipv4": {Label: "כתובת IPv4", Gender: "f"},
"ipv6": {Label: "כתובת IPv6", Gender: "f"},
"mac": {Label: "כתובת MAC", Gender: "f"},
"cidrv4": {Label: "טווח IPv4", Gender: "m"},
"cidrv6": {Label: "טווח IPv6", Gender: "m"},
"base64": {Label: "מחרוזת בבסיס 64", Gender: "f"},
"base64url": {Label: "מחרוזת בבסיס 64 לכתובות רשת", Gender: "f"},
"json_string": {Label: "מחרוזת JSON", Gender: "f"},
"e164": {Label: "מספר E.164", Gender: "m"},
"jwt": {Label: "JWT", Gender: "m"},
"template_literal": {Label: "קלט", Gender: "m"},
}
FormatNounsHe maps Hebrew format noun translations with gender.
var FormatNounsHu = map[string]string{
"regex": "bemenet",
"email": "email cím",
"url": "URL",
"emoji": "emoji",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "ISO időbélyeg",
"date": "ISO dátum",
"time": "ISO idő",
"duration": "ISO időintervallum",
"ipv4": "IPv4 cím",
"ipv6": "IPv6 cím",
"mac": "MAC cím",
"cidrv4": "IPv4 tartomány",
"cidrv6": "IPv6 tartomány",
"base64": "base64-kódolt string",
"base64url": "base64url-kódolt string",
"json_string": "JSON string",
"e164": "E.164 szám",
"jwt": "JWT",
"template_literal": "bemenet",
}
FormatNounsHu maps Hungarian format noun translations.
var FormatNounsID = map[string]string{
"regex": "input",
"email": "alamat email",
"url": "URL",
"emoji": "emoji",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "tanggal dan waktu format ISO",
"date": "tanggal format ISO",
"time": "jam format ISO",
"duration": "durasi format ISO",
"ipv4": "alamat IPv4",
"ipv6": "alamat IPv6",
"mac": "alamat MAC",
"cidrv4": "rentang alamat IPv4",
"cidrv6": "rentang alamat IPv6",
"base64": "string dengan enkode base64",
"base64url": "string dengan enkode base64url",
"json_string": "string JSON",
"e164": "angka E.164",
"jwt": "JWT",
"template_literal": "input",
}
FormatNounsID maps Indonesian format noun translations.
var FormatNounsIt = map[string]string{
"regex": "input",
"email": "indirizzo email",
"url": "URL",
"emoji": "emoji",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "data e ora ISO",
"date": "data ISO",
"time": "ora ISO",
"duration": "durata ISO",
"ipv4": "indirizzo IPv4",
"ipv6": "indirizzo IPv6",
"mac": "indirizzo MAC",
"cidrv4": "intervallo IPv4",
"cidrv6": "intervallo IPv6",
"base64": "stringa codificata in base64",
"base64url": "URL codificata in base64",
"json_string": "stringa JSON",
"e164": "numero E.164",
"jwt": "JWT",
"template_literal": "input",
}
FormatNounsIt maps Italian format noun translations.
var FormatNounsJa = map[string]string{
"regex": "入力値",
"email": "メールアドレス",
"url": "URL",
"emoji": "絵文字",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "ISO日時",
"date": "ISO日付",
"time": "ISO時刻",
"duration": "ISO期間",
"ipv4": "IPv4アドレス",
"ipv6": "IPv6アドレス",
"mac": "MACアドレス",
"cidrv4": "IPv4範囲",
"cidrv6": "IPv6範囲",
"base64": "base64エンコード文字列",
"base64url": "base64urlエンコード文字列",
"json_string": "JSON文字列",
"e164": "E.164番号",
"jwt": "JWT",
"template_literal": "入力値",
}
FormatNounsJa maps Japanese format noun translations.
var FormatNounsKo = map[string]string{
"regex": "입력",
"email": "이메일 주소",
"url": "URL",
"emoji": "이모지",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "ISO 날짜시간",
"date": "ISO 날짜",
"time": "ISO 시간",
"duration": "ISO 기간",
"ipv4": "IPv4 주소",
"ipv6": "IPv6 주소",
"mac": "MAC 주소",
"cidrv4": "IPv4 범위",
"cidrv6": "IPv6 범위",
"base64": "base64 인코딩 문자열",
"base64url": "base64url 인코딩 문자열",
"json_string": "JSON 문자열",
"e164": "E.164 번호",
"jwt": "JWT",
"template_literal": "입력",
}
FormatNounsKo maps Korean format noun translations.
var FormatNounsMs = map[string]string{
"regex": "input",
"email": "alamat e-mel",
"url": "URL",
"emoji": "emoji",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "tarikh masa ISO",
"date": "tarikh ISO",
"time": "masa ISO",
"duration": "tempoh ISO",
"ipv4": "alamat IPv4",
"ipv6": "alamat IPv6",
"mac": "alamat MAC",
"cidrv4": "julat IPv4",
"cidrv6": "julat IPv6",
"base64": "string dikodkan base64",
"base64url": "string dikodkan base64url",
"json_string": "string JSON",
"e164": "nombor E.164",
"jwt": "JWT",
"template_literal": "input",
}
FormatNounsMs maps Malay format noun translations.
var FormatNounsNl = map[string]string{
"regex": "invoer",
"email": "emailadres",
"url": "URL",
"emoji": "emoji",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "ISO datum en tijd",
"date": "ISO datum",
"time": "ISO tijd",
"duration": "ISO duur",
"ipv4": "IPv4-adres",
"ipv6": "IPv6-adres",
"mac": "MAC-adres",
"cidrv4": "IPv4-bereik",
"cidrv6": "IPv6-bereik",
"base64": "base64-gecodeerde tekst",
"base64url": "base64 URL-gecodeerde tekst",
"json_string": "JSON string",
"e164": "E.164-nummer",
"jwt": "JWT",
"template_literal": "invoer",
}
FormatNounsNl maps Dutch format noun translations.
var FormatNounsNo = map[string]string{
"regex": "input",
"email": "e-postadresse",
"url": "URL",
"emoji": "emoji",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "ISO dato- og klokkeslett",
"date": "ISO-dato",
"time": "ISO-klokkeslett",
"duration": "ISO-varighet",
"ipv4": "IPv4-adresse",
"ipv6": "IPv6-adresse",
"mac": "MAC-adresse",
"cidrv4": "IPv4-spekter",
"cidrv6": "IPv6-spekter",
"base64": "base64-enkodet streng",
"base64url": "base64url-enkodet streng",
"json_string": "JSON-streng",
"e164": "E.164-nummer",
"jwt": "JWT",
"template_literal": "input",
}
FormatNounsNo maps Norwegian format noun translations.
var FormatNounsPl = map[string]string{
"regex": "wyrażenie",
"email": "adres email",
"url": "URL",
"emoji": "emoji",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "data i godzina w formacie ISO",
"date": "data w formacie ISO",
"time": "godzina w formacie ISO",
"duration": "czas trwania ISO",
"ipv4": "adres IPv4",
"ipv6": "adres IPv6",
"mac": "adres MAC",
"cidrv4": "zakres IPv4",
"cidrv6": "zakres IPv6",
"base64": "ciąg znaków zakodowany w formacie base64",
"base64url": "ciąg znaków zakodowany w formacie base64url",
"json_string": "ciąg znaków w formacie JSON",
"e164": "liczba E.164",
"jwt": "JWT",
"template_literal": "wejście",
}
FormatNounsPl maps Polish format noun translations.
var FormatNounsPt = map[string]string{
"regex": "padrão",
"email": "endereço de e-mail",
"url": "URL",
"emoji": "emoji",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "data e hora ISO",
"date": "data ISO",
"time": "hora ISO",
"duration": "duração ISO",
"ipv4": "endereço IPv4",
"ipv6": "endereço IPv6",
"mac": "endereço MAC",
"cidrv4": "faixa de IPv4",
"cidrv6": "faixa de IPv6",
"base64": "texto codificado em base64",
"base64url": "URL codificada em base64",
"json_string": "texto JSON",
"e164": "número E.164",
"jwt": "JWT",
"template_literal": "entrada",
}
FormatNounsPt maps Portuguese format noun translations.
var FormatNounsRu = map[string]string{
"regex": "ввод",
"email": "email адрес",
"url": "URL",
"emoji": "эмодзи",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "ISO дата и время",
"date": "ISO дата",
"time": "ISO время",
"duration": "ISO длительность",
"ipv4": "IPv4 адрес",
"ipv6": "IPv6 адрес",
"mac": "MAC адрес",
"cidrv4": "IPv4 диапазон",
"cidrv6": "IPv6 диапазон",
"base64": "строка в формате base64",
"base64url": "строка в формате base64url",
"json_string": "JSON строка",
"e164": "номер E.164",
"jwt": "JWT",
"template_literal": "ввод",
}
FormatNounsRu maps Russian format noun translations.
var FormatNounsSv = map[string]string{
"regex": "reguljärt uttryck",
"email": "e-postadress",
"url": "URL",
"emoji": "emoji",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "ISO-datum och tid",
"date": "ISO-datum",
"time": "ISO-tid",
"duration": "ISO-varaktighet",
"ipv4": "IPv4-adress",
"ipv6": "IPv6-adress",
"mac": "MAC-adress",
"cidrv4": "IPv4-spektrum",
"cidrv6": "IPv6-spektrum",
"base64": "base64-kodad sträng",
"base64url": "base64url-kodad sträng",
"json_string": "JSON-sträng",
"e164": "E.164-nummer",
"jwt": "JWT",
"template_literal": "mall-literal",
}
FormatNounsSv maps Swedish format noun translations.
var FormatNounsTa = map[string]string{
"regex": "உள்ளீடு",
"email": "மின்னஞ்சல் முகவரி",
"url": "URL",
"emoji": "emoji",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "ISO தேதி நேரம்",
"date": "ISO தேதி",
"time": "ISO நேரம்",
"duration": "ISO கால அளவு",
"ipv4": "IPv4 முகவரி",
"ipv6": "IPv6 முகவரி",
"mac": "MAC முகவரி",
"cidrv4": "IPv4 வரம்பு",
"cidrv6": "IPv6 வரம்பு",
"base64": "base64-encoded சரம்",
"base64url": "base64url-encoded சரம்",
"json_string": "JSON சரம்",
"e164": "E.164 எண்",
"jwt": "JWT",
"template_literal": "உள்ளீடு",
}
FormatNounsTa maps Tamil format noun translations.
var FormatNounsTh = map[string]string{
"regex": "ข้อมูลที่ป้อน",
"email": "ที่อยู่อีเมล",
"url": "URL",
"emoji": "อิโมจิ",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "วันที่เวลาแบบ ISO",
"date": "วันที่แบบ ISO",
"time": "เวลาแบบ ISO",
"duration": "ช่วงเวลาแบบ ISO",
"ipv4": "ที่อยู่ IPv4",
"ipv6": "ที่อยู่ IPv6",
"mac": "ที่อยู่ MAC",
"cidrv4": "ช่วง IP แบบ IPv4",
"cidrv6": "ช่วง IP แบบ IPv6",
"base64": "ข้อความแบบ Base64",
"base64url": "ข้อความแบบ Base64 สำหรับ URL",
"json_string": "ข้อความแบบ JSON",
"e164": "เบอร์โทรศัพท์ระหว่างประเทศ (E.164)",
"jwt": "โทเคน JWT",
"template_literal": "ข้อมูลที่ป้อน",
}
FormatNounsTh maps Thai format noun translations.
var FormatNounsTr = map[string]string{
"regex": "girdi",
"email": "e-posta adresi",
"url": "URL",
"emoji": "emoji",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "ISO tarih ve saat",
"date": "ISO tarih",
"time": "ISO saat",
"duration": "ISO süre",
"ipv4": "IPv4 adresi",
"ipv6": "IPv6 adresi",
"mac": "MAC adresi",
"cidrv4": "IPv4 aralığı",
"cidrv6": "IPv6 aralığı",
"base64": "base64 ile şifrelenmiş metin",
"base64url": "base64url ile şifrelenmiş metin",
"json_string": "JSON dizesi",
"e164": "E.164 sayısı",
"jwt": "JWT",
"template_literal": "şablon dizesi",
}
FormatNounsTr maps Turkish format noun translations.
var FormatNounsUk = map[string]string{
"regex": "вхідні дані",
"email": "адреса електронної пошти",
"url": "URL",
"emoji": "емодзі",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "дата та час ISO",
"date": "дата ISO",
"time": "час ISO",
"duration": "тривалість ISO",
"ipv4": "адреса IPv4",
"ipv6": "адреса IPv6",
"mac": "адреса MAC",
"cidrv4": "діапазон IPv4",
"cidrv6": "діапазон IPv6",
"base64": "рядок у кодуванні base64",
"base64url": "рядок у кодуванні base64url",
"json_string": "рядок JSON",
"e164": "номер E.164",
"jwt": "JWT",
"template_literal": "вхідні дані",
}
FormatNounsUk maps Ukrainian format noun translations.
var FormatNounsUr = map[string]string{
"regex": "ان پٹ",
"email": "ای میل ایڈریس",
"url": "یو آر ایل",
"emoji": "ایموجی",
"uuid": "یو یو آئی ڈی",
"uuidv4": "یو یو آئی ڈی وی 4",
"uuidv6": "یو یو آئی ڈی وی 6",
"nanoid": "نینو آئی ڈی",
"guid": "جی یو آئی ڈی",
"cuid": "سی یو آئی ڈی",
"cuid2": "سی یو آئی ڈی 2",
"ulid": "یو ایل آئی ڈی",
"xid": "ایکس آئی ڈی",
"ksuid": "کے ایس یو آئی ڈی",
"datetime": "آئی ایس او ڈیٹ ٹائم",
"date": "آئی ایس او تاریخ",
"time": "آئی ایس او وقت",
"duration": "آئی ایس او مدت",
"ipv4": "آئی پی وی 4 ایڈریس",
"ipv6": "آئی پی وی 6 ایڈریس",
"mac": "میک ایڈریس",
"cidrv4": "آئی پی وی 4 رینج",
"cidrv6": "آئی پی وی 6 رینج",
"base64": "بیس 64 ان کوڈڈ سٹرنگ",
"base64url": "بیس 64 یو آر ایل ان کوڈڈ سٹرنگ",
"json_string": "جے ایس او این سٹرنگ",
"e164": "ای 164 نمبر",
"jwt": "جے ڈبلیو ٹی",
"template_literal": "ان پٹ",
}
FormatNounsUr maps Urdu format noun translations.
var FormatNounsVi = map[string]string{
"regex": "đầu vào",
"email": "địa chỉ email",
"url": "URL",
"emoji": "emoji",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "ngày giờ ISO",
"date": "ngày ISO",
"time": "giờ ISO",
"duration": "khoảng thời gian ISO",
"ipv4": "địa chỉ IPv4",
"ipv6": "địa chỉ IPv6",
"mac": "địa chỉ MAC",
"cidrv4": "dải IPv4",
"cidrv6": "dải IPv6",
"base64": "chuỗi mã hóa base64",
"base64url": "chuỗi mã hóa base64url",
"json_string": "chuỗi JSON",
"e164": "số E.164",
"jwt": "JWT",
"template_literal": "đầu vào",
}
FormatNounsVi maps Vietnamese format noun translations.
var FormatNounsZh = map[string]string{
"regex": "输入",
"email": "电子邮件",
"url": "URL",
"emoji": "表情符号",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "ISO日期时间",
"date": "ISO日期",
"time": "ISO时间",
"duration": "ISO时长",
"ipv4": "IPv4地址",
"ipv6": "IPv6地址",
"cidrv4": "IPv4网段",
"cidrv6": "IPv6网段",
"base64": "base64编码字符串",
"base64url": "base64url编码字符串",
"json_string": "JSON字符串",
"e164": "E.164号码",
"jwt": "JWT",
"template_literal": "输入",
"int8": "8位整数",
"int16": "16位整数",
"int32": "32位整数",
"int64": "64位整数",
"uint8": "8位无符号整数",
"uint16": "16位无符号整数",
"uint32": "32位无符号整数",
"uint64": "64位无符号整数",
"float32": "32位浮点数",
"float64": "64位浮点数",
"complex64": "64位复数",
"complex128": "128位复数",
}
FormatNounsZh maps Chinese format noun translations.
var FormatNounsZhTw = map[string]string{
"regex": "輸入",
"email": "郵件地址",
"url": "URL",
"emoji": "emoji",
"uuid": "UUID",
"uuidv4": "UUIDv4",
"uuidv6": "UUIDv6",
"nanoid": "nanoid",
"guid": "GUID",
"cuid": "cuid",
"cuid2": "cuid2",
"ulid": "ULID",
"xid": "XID",
"ksuid": "KSUID",
"datetime": "ISO 日期時間",
"date": "ISO 日期",
"time": "ISO 時間",
"duration": "ISO 期間",
"ipv4": "IPv4 位址",
"ipv6": "IPv6 位址",
"mac": "MAC 位址",
"cidrv4": "IPv4 範圍",
"cidrv6": "IPv6 範圍",
"base64": "base64 編碼字串",
"base64url": "base64url 編碼字串",
"json_string": "JSON 字串",
"e164": "E.164 數值",
"jwt": "JWT",
"template_literal": "輸入",
}
FormatNounsZhTw maps Traditional Chinese format noun translations.
var SizableAr = map[string]issues.SizingInfo{
"string": {Unit: "حرف", Verb: "أن يحوي"},
"file": {Unit: "بايت", Verb: "أن يحوي"},
"array": {Unit: "عنصر", Verb: "أن يحوي"},
"slice": {Unit: "عنصر", Verb: "أن يحوي"},
"set": {Unit: "عنصر", Verb: "أن يحوي"},
"map": {Unit: "مدخل", Verb: "أن يحوي"},
}
SizableAr maps Arabic sizing information.
var SizableBg = map[string]issues.SizingInfo{
"string": {Unit: "символа", Verb: "да съдържа"},
"file": {Unit: "байта", Verb: "да съдържа"},
"array": {Unit: "елемента", Verb: "да съдържа"},
"slice": {Unit: "елемента", Verb: "да съдържа"},
"set": {Unit: "елемента", Verb: "да съдържа"},
"map": {Unit: "записа", Verb: "да съдържа"},
}
SizableBg maps Bulgarian sizing information.
var SizableCs = map[string]issues.SizingInfo{
"string": {Unit: "znaků", Verb: "mít"},
"file": {Unit: "bajtů", Verb: "mít"},
"array": {Unit: "prvků", Verb: "mít"},
"slice": {Unit: "prvků", Verb: "mít"},
"set": {Unit: "prvků", Verb: "mít"},
"map": {Unit: "záznamů", Verb: "mít"},
}
SizableCs maps Czech sizing information.
var SizableDa = map[string]issues.SizingInfo{
"string": {Unit: "tegn", Verb: "havde"},
"file": {Unit: "bytes", Verb: "havde"},
"array": {Unit: "elementer", Verb: "indeholdt"},
"slice": {Unit: "elementer", Verb: "indeholdt"},
"set": {Unit: "elementer", Verb: "indeholdt"},
"map": {Unit: "poster", Verb: "indeholdt"},
}
SizableDa maps Danish sizing information.
var SizableDe = map[string]issues.SizingInfo{
"string": {Unit: "Zeichen", Verb: "haben"},
"file": {Unit: "Bytes", Verb: "haben"},
"array": {Unit: "Elemente", Verb: "haben"},
"slice": {Unit: "Elemente", Verb: "haben"},
"set": {Unit: "Elemente", Verb: "haben"},
"map": {Unit: "Einträge", Verb: "haben"},
}
SizableDe maps German sizing information.
var SizableEs = map[string]issues.SizingInfo{
"string": {Unit: "caracteres", Verb: "tener"},
"file": {Unit: "bytes", Verb: "tener"},
"array": {Unit: "elementos", Verb: "tener"},
"slice": {Unit: "elementos", Verb: "tener"},
"set": {Unit: "elementos", Verb: "tener"},
"map": {Unit: "entradas", Verb: "tener"},
}
SizableEs maps Spanish sizing information.
var SizableFa = map[string]issues.SizingInfo{
"string": {Unit: "کاراکتر", Verb: "داشته باشد"},
"file": {Unit: "بایت", Verb: "داشته باشد"},
"array": {Unit: "آیتم", Verb: "داشته باشد"},
"slice": {Unit: "آیتم", Verb: "داشته باشد"},
"set": {Unit: "آیتم", Verb: "داشته باشد"},
"map": {Unit: "ورودی", Verb: "داشته باشد"},
}
Persian sizing info mappings
var SizableFi = map[string]finnishSizingInfo{
"string": {Unit: "merkkiä", Subject: "merkkijonon"},
"file": {Unit: "tavua", Subject: "tiedoston"},
"array": {Unit: "alkiota", Subject: "listan"},
"slice": {Unit: "alkiota", Subject: "listan"},
"set": {Unit: "alkiota", Subject: "joukon"},
"map": {Unit: "merkintää", Subject: "kartan"},
"number": {Unit: "", Subject: "luvun"},
"bigint": {Unit: "", Subject: "suuren kokonaisluvun"},
"int": {Unit: "", Subject: "kokonaisluvun"},
"date": {Unit: "", Subject: "päivämäärän"},
}
SizableFi maps Finnish sizing information.
var SizableFr = map[string]issues.SizingInfo{
"string": {Unit: "caractères", Verb: "avoir"},
"file": {Unit: "octets", Verb: "avoir"},
"array": {Unit: "éléments", Verb: "avoir"},
"slice": {Unit: "éléments", Verb: "avoir"},
"set": {Unit: "éléments", Verb: "avoir"},
"map": {Unit: "entrées", Verb: "avoir"},
}
SizableFr maps French sizing information.
var SizableHe = map[string]hebrewSizingInfo{
"string": {Unit: "תווים", ShortLabel: "קצר", LongLabel: "ארוך"},
"file": {Unit: "בייטים", ShortLabel: "קטן", LongLabel: "גדול"},
"array": {Unit: "פריטים", ShortLabel: "קטן", LongLabel: "גדול"},
"slice": {Unit: "פריטים", ShortLabel: "קטן", LongLabel: "גדול"},
"set": {Unit: "פריטים", ShortLabel: "קטן", LongLabel: "גדול"},
"map": {Unit: "פריטים", ShortLabel: "קטן", LongLabel: "גדול"},
"number": {Unit: "", ShortLabel: "קטן", LongLabel: "גדול"},
}
SizableHe maps Hebrew sizing information.
var SizableHu = map[string]issues.SizingInfo{
"string": {Unit: "karakter", Verb: "legyen"},
"file": {Unit: "byte", Verb: "legyen"},
"array": {Unit: "elem", Verb: "legyen"},
"slice": {Unit: "elem", Verb: "legyen"},
"set": {Unit: "elem", Verb: "legyen"},
"map": {Unit: "bejegyzés", Verb: "legyen"},
}
SizableHu maps Hungarian sizing information.
var SizableID = map[string]issues.SizingInfo{
"string": {Unit: "karakter", Verb: "memiliki"},
"file": {Unit: "byte", Verb: "memiliki"},
"array": {Unit: "item", Verb: "memiliki"},
"slice": {Unit: "item", Verb: "memiliki"},
"set": {Unit: "item", Verb: "memiliki"},
"map": {Unit: "entri", Verb: "memiliki"},
}
SizableID maps Indonesian sizing information.
var SizableIt = map[string]issues.SizingInfo{
"string": {Unit: "caratteri", Verb: "avere"},
"file": {Unit: "byte", Verb: "avere"},
"array": {Unit: "elementi", Verb: "avere"},
"slice": {Unit: "elementi", Verb: "avere"},
"set": {Unit: "elementi", Verb: "avere"},
"map": {Unit: "voci", Verb: "avere"},
}
SizableIt maps Italian sizing information.
var SizableJa = map[string]issues.SizingInfo{
"string": {Unit: "文字", Verb: "である"},
"file": {Unit: "バイト", Verb: "である"},
"array": {Unit: "要素", Verb: "である"},
"slice": {Unit: "要素", Verb: "である"},
"set": {Unit: "要素", Verb: "である"},
"map": {Unit: "エントリ", Verb: "である"},
}
SizableJa maps Japanese sizing information.
var SizableKo = map[string]issues.SizingInfo{
"string": {Unit: "문자", Verb: ""},
"file": {Unit: "바이트", Verb: ""},
"array": {Unit: "개", Verb: ""},
"slice": {Unit: "개", Verb: ""},
"set": {Unit: "개", Verb: ""},
"map": {Unit: "개", Verb: ""},
}
SizableKo maps Korean sizing information.
var SizableMs = map[string]issues.SizingInfo{
"string": {Unit: "aksara", Verb: "mempunyai"},
"file": {Unit: "bait", Verb: "mempunyai"},
"array": {Unit: "elemen", Verb: "mempunyai"},
"slice": {Unit: "elemen", Verb: "mempunyai"},
"set": {Unit: "elemen", Verb: "mempunyai"},
"map": {Unit: "entri", Verb: "mempunyai"},
}
SizableMs maps Malay sizing information.
var SizableNl = map[string]issues.SizingInfo{
"string": {Unit: "tekens", Verb: "heeft"},
"file": {Unit: "bytes", Verb: "heeft"},
"array": {Unit: "elementen", Verb: "heeft"},
"slice": {Unit: "elementen", Verb: "heeft"},
"set": {Unit: "elementen", Verb: "heeft"},
"map": {Unit: "items", Verb: "heeft"},
}
SizableNl maps Dutch sizing information.
var SizableNo = map[string]issues.SizingInfo{
"string": {Unit: "tegn", Verb: "å ha"},
"file": {Unit: "bytes", Verb: "å ha"},
"array": {Unit: "elementer", Verb: "å inneholde"},
"slice": {Unit: "elementer", Verb: "å inneholde"},
"set": {Unit: "elementer", Verb: "å inneholde"},
"map": {Unit: "oppføringer", Verb: "å inneholde"},
}
SizableNo maps Norwegian sizing information.
var SizablePl = map[string]issues.SizingInfo{
"string": {Unit: "znaków", Verb: "mieć"},
"file": {Unit: "bajtów", Verb: "mieć"},
"array": {Unit: "elementów", Verb: "mieć"},
"slice": {Unit: "elementów", Verb: "mieć"},
"set": {Unit: "elementów", Verb: "mieć"},
"map": {Unit: "wpisów", Verb: "mieć"},
}
SizablePl maps Polish sizing information.
var SizablePt = map[string]issues.SizingInfo{
"string": {Unit: "caracteres", Verb: "ter"},
"file": {Unit: "bytes", Verb: "ter"},
"array": {Unit: "itens", Verb: "ter"},
"slice": {Unit: "itens", Verb: "ter"},
"set": {Unit: "itens", Verb: "ter"},
"map": {Unit: "entradas", Verb: "ter"},
}
SizablePt maps Portuguese sizing information.
var SizableRu = map[string]RussianSizable{
"string": {UnitOne: "символ", UnitFew: "символа", UnitMany: "символов", Verb: "иметь"},
"file": {UnitOne: "байт", UnitFew: "байта", UnitMany: "байт", Verb: "иметь"},
"array": {UnitOne: "элемент", UnitFew: "элемента", UnitMany: "элементов", Verb: "иметь"},
"slice": {UnitOne: "элемент", UnitFew: "элемента", UnitMany: "элементов", Verb: "иметь"},
"set": {UnitOne: "элемент", UnitFew: "элемента", UnitMany: "элементов", Verb: "иметь"},
"map": {UnitOne: "запись", UnitFew: "записи", UnitMany: "записей", Verb: "иметь"},
}
SizableRu maps Russian sizing information with plural forms.
var SizableSv = map[string]issues.SizingInfo{
"string": {Unit: "tecken", Verb: "att ha"},
"file": {Unit: "bytes", Verb: "att ha"},
"array": {Unit: "objekt", Verb: "att innehålla"},
"slice": {Unit: "objekt", Verb: "att innehålla"},
"set": {Unit: "objekt", Verb: "att innehålla"},
"map": {Unit: "poster", Verb: "att innehålla"},
}
SizableSv maps Swedish sizing information.
var SizableTa = map[string]issues.SizingInfo{
"string": {Unit: "எழுத்துக்கள்", Verb: "கொண்டிருக்க வேண்டும்"},
"file": {Unit: "பைட்டுகள்", Verb: "கொண்டிருக்க வேண்டும்"},
"array": {Unit: "உறுப்புகள்", Verb: "கொண்டிருக்க வேண்டும்"},
"slice": {Unit: "உறுப்புகள்", Verb: "கொண்டிருக்க வேண்டும்"},
"set": {Unit: "உறுப்புகள்", Verb: "கொண்டிருக்க வேண்டும்"},
"map": {Unit: "உள்ளீடுகள்", Verb: "கொண்டிருக்க வேண்டும்"},
}
SizableTa maps Tamil sizing information.
var SizableTh = map[string]issues.SizingInfo{
"string": {Unit: "ตัวอักษร", Verb: "ควรมี"},
"file": {Unit: "ไบต์", Verb: "ควรมี"},
"array": {Unit: "รายการ", Verb: "ควรมี"},
"slice": {Unit: "รายการ", Verb: "ควรมี"},
"set": {Unit: "รายการ", Verb: "ควรมี"},
"map": {Unit: "รายการ", Verb: "ควรมี"},
}
SizableTh maps Thai sizing information.
var SizableTr = map[string]issues.SizingInfo{
"string": {Unit: "karakter", Verb: "olmalı"},
"file": {Unit: "bayt", Verb: "olmalı"},
"array": {Unit: "öğe", Verb: "olmalı"},
"slice": {Unit: "öğe", Verb: "olmalı"},
"set": {Unit: "öğe", Verb: "olmalı"},
"map": {Unit: "girdi", Verb: "olmalı"},
}
SizableTr maps Turkish sizing information.
var SizableUk = map[string]issues.SizingInfo{
"string": {Unit: "символів", Verb: "матиме"},
"file": {Unit: "байтів", Verb: "матиме"},
"array": {Unit: "елементів", Verb: "матиме"},
"slice": {Unit: "елементів", Verb: "матиме"},
"set": {Unit: "елементів", Verb: "матиме"},
"map": {Unit: "записів", Verb: "матиме"},
}
SizableUk maps Ukrainian sizing information.
var SizableUr = map[string]issues.SizingInfo{
"string": {Unit: "حروف", Verb: "ہونا"},
"file": {Unit: "بائٹس", Verb: "ہونا"},
"array": {Unit: "آئٹمز", Verb: "ہونا"},
"slice": {Unit: "آئٹمز", Verb: "ہونا"},
"set": {Unit: "آئٹمز", Verb: "ہونا"},
"map": {Unit: "اندراجات", Verb: "ہونا"},
}
SizableUr maps Urdu sizing information.
var SizableVi = map[string]issues.SizingInfo{
"string": {Unit: "ký tự", Verb: "có"},
"file": {Unit: "byte", Verb: "có"},
"array": {Unit: "phần tử", Verb: "có"},
"slice": {Unit: "phần tử", Verb: "có"},
"set": {Unit: "phần tử", Verb: "có"},
"map": {Unit: "mục", Verb: "có"},
}
SizableVi maps Vietnamese sizing information.
var SizableZh = map[string]issues.SizingInfo{
"string": {Unit: "字符", Verb: "包含"},
"file": {Unit: "字节", Verb: "包含"},
"array": {Unit: "项", Verb: "包含"},
"slice": {Unit: "项", Verb: "包含"},
"set": {Unit: "项", Verb: "包含"},
"object": {Unit: "键", Verb: "包含"},
"map": {Unit: "键", Verb: "包含"},
}
SizableZh maps Chinese sizing information.
var SizableZhTw = map[string]issues.SizingInfo{
"string": {Unit: "字元", Verb: "擁有"},
"file": {Unit: "位元組", Verb: "擁有"},
"array": {Unit: "項目", Verb: "擁有"},
"slice": {Unit: "項目", Verb: "擁有"},
"set": {Unit: "項目", Verb: "擁有"},
"map": {Unit: "項目", Verb: "擁有"},
}
SizableZhTw maps Traditional Chinese sizing information.
var TypeDictionaryAr = map[string]string{
"nan": "NaN",
"number": "رقم",
"array": "مصفوفة",
"slice": "مصفوفة",
"string": "نَص",
"bool": "قيمة منطقية",
"object": "كائن",
"map": "خريطة",
"nil": "فارغ",
"undefined": "غير معرّف",
"function": "دالة",
"date": "تاريخ",
"file": "ملف",
"set": "مجموعة",
}
TypeDictionaryAr maps Arabic type name translations.
var TypeDictionaryBg = map[string]string{
"nan": "NaN",
"number": "число",
"array": "масив",
"slice": "масив",
"string": "низ",
"bool": "булево",
"object": "обект",
"map": "карта",
"nil": "null",
"undefined": "неопределено",
"function": "функция",
"date": "дата",
"file": "файл",
"set": "множество",
}
TypeDictionaryBg maps Bulgarian type name translations.
var TypeDictionaryCs = map[string]string{
"nan": "NaN",
"number": "číslo",
"array": "pole",
"slice": "pole",
"string": "řetězec",
"bool": "boolean",
"object": "objekt",
"map": "mapa",
"nil": "null",
"undefined": "nedefinováno",
"function": "funkce",
"date": "datum",
"file": "soubor",
"set": "množina",
}
TypeDictionaryCs maps Czech type name translations.
var TypeDictionaryDa = map[string]string{
"nan": "NaN",
"number": "tal",
"array": "liste",
"slice": "liste",
"string": "streng",
"bool": "boolean",
"object": "objekt",
"map": "kort",
"nil": "null",
"undefined": "udefineret",
"function": "funktion",
"date": "dato",
"file": "fil",
"set": "sæt",
}
TypeDictionaryDa maps Danish type name translations.
var TypeDictionaryDe = map[string]string{
"nan": "NaN",
"number": "Zahl",
"array": "Array",
"slice": "Array",
"string": "String",
"bool": "Boolean",
"object": "Objekt",
"map": "Map",
"nil": "null",
"undefined": "undefined",
"function": "Funktion",
"date": "Datum",
"file": "Datei",
"set": "Set",
}
TypeDictionaryDe maps German type name translations.
var TypeDictionaryEs = map[string]string{
"nan": "NaN",
"string": "texto",
"number": "número",
"boolean": "booleano",
"bool": "booleano",
"array": "arreglo",
"slice": "arreglo",
"object": "objeto",
"set": "conjunto",
"file": "archivo",
"date": "fecha",
"bigint": "número grande",
"symbol": "símbolo",
"undefined": "indefinido",
"nil": "nulo",
"null": "nulo",
"function": "función",
"map": "mapa",
"record": "registro",
"tuple": "tupla",
"enum": "enumeración",
"union": "unión",
"literal": "literal",
"promise": "promesa",
"void": "vacío",
"never": "nunca",
"unknown": "desconocido",
"any": "cualquiera",
}
TypeDictionaryEs maps Spanish type name translations.
var TypeDictionaryFa = map[string]string{
"nan": "NaN",
"number": "عدد",
"array": "آرایه",
"slice": "آرایه",
"string": "رشته",
"bool": "بولی",
"object": "شیء",
"map": "نقشه",
"nil": "تهی",
"undefined": "تعریف نشده",
"function": "تابع",
"date": "تاریخ",
"file": "فایل",
"set": "مجموعه",
}
Persian type dictionary
var TypeDictionaryFi = map[string]string{
"nan": "NaN",
"number": "numero",
"array": "lista",
"slice": "lista",
"string": "merkkijono",
"bool": "totuusarvo",
"object": "objekti",
"map": "kartta",
"nil": "null",
"undefined": "määrittelemätön",
"function": "funktio",
"date": "päivämäärä",
"file": "tiedosto",
"set": "joukko",
}
TypeDictionaryFi maps Finnish type name translations.
var TypeDictionaryFr = map[string]string{
"nan": "NaN",
"number": "nombre",
"array": "tableau",
"slice": "tableau",
"string": "chaîne",
"bool": "booléen",
"object": "objet",
"map": "map",
"nil": "null",
"undefined": "undefined",
"function": "fonction",
"date": "date",
"file": "fichier",
"set": "ensemble",
}
TypeDictionaryFr maps French type name translations.
var TypeDictionaryHu = map[string]string{
"nan": "NaN",
"number": "szám",
"array": "tömb",
"slice": "tömb",
"string": "szöveg",
"bool": "logikai érték",
"object": "objektum",
"map": "térkép",
"nil": "null",
"undefined": "meghatározatlan",
"function": "függvény",
"date": "dátum",
"file": "fájl",
"set": "halmaz",
}
TypeDictionaryHu maps Hungarian type name translations.
var TypeDictionaryID = map[string]string{
"nan": "NaN",
"number": "angka",
"array": "array",
"slice": "array",
"string": "string",
"bool": "boolean",
"object": "objek",
"map": "peta",
"nil": "null",
"undefined": "tidak terdefinisi",
"function": "fungsi",
"date": "tanggal",
"file": "file",
"set": "set",
}
TypeDictionaryID maps Indonesian type name translations.
var TypeDictionaryIt = map[string]string{
"nan": "NaN",
"number": "numero",
"array": "vettore",
"slice": "vettore",
"string": "stringa",
"bool": "booleano",
"object": "oggetto",
"map": "mappa",
"nil": "nullo",
"undefined": "indefinito",
"function": "funzione",
"date": "data",
"file": "file",
"set": "insieme",
}
TypeDictionaryIt maps Italian type name translations.
var TypeDictionaryJa = map[string]string{
"nan": "NaN",
"number": "数値",
"array": "配列",
"slice": "配列",
"string": "文字列",
"bool": "真偽値",
"object": "オブジェクト",
"map": "マップ",
"nil": "null",
"undefined": "undefined",
"function": "関数",
"date": "日付",
"file": "ファイル",
"set": "セット",
}
TypeDictionaryJa maps Japanese type name translations.
var TypeDictionaryKo = map[string]string{
"nan": "NaN",
"number": "숫자",
"array": "배열",
"slice": "배열",
"string": "문자열",
"bool": "불리언",
"object": "객체",
"map": "맵",
"nil": "null",
"undefined": "undefined",
"function": "함수",
"date": "날짜",
"file": "파일",
"set": "세트",
}
TypeDictionaryKo maps Korean type name translations.
var TypeDictionaryMs = map[string]string{
"nan": "NaN",
"number": "nombor",
"array": "senarai",
"slice": "senarai",
"string": "rentetan",
"bool": "boolean",
"object": "objek",
"map": "peta",
"nil": "null",
"undefined": "tidak ditakrifkan",
"function": "fungsi",
"date": "tarikh",
"file": "fail",
"set": "set",
}
TypeDictionaryMs maps Malay type name translations.
var TypeDictionaryNl = map[string]string{
"nan": "NaN",
"number": "getal",
"array": "array",
"slice": "array",
"string": "tekst",
"bool": "boolean",
"object": "object",
"map": "map",
"nil": "null",
"undefined": "ongedefinieerd",
"function": "functie",
"date": "datum",
"file": "bestand",
"set": "set",
}
TypeDictionaryNl maps Dutch type name translations.
var TypeDictionaryNo = map[string]string{
"nan": "NaN",
"number": "tall",
"array": "liste",
"slice": "liste",
"string": "streng",
"bool": "boolsk verdi",
"object": "objekt",
"map": "kart",
"nil": "null",
"undefined": "udefinert",
"function": "funksjon",
"date": "dato",
"file": "fil",
"set": "sett",
}
TypeDictionaryNo maps Norwegian type name translations.
var TypeDictionaryPl = map[string]string{
"nan": "NaN",
"number": "liczba",
"array": "tablica",
"slice": "tablica",
"string": "ciąg znaków",
"bool": "wartość logiczna",
"object": "obiekt",
"map": "mapa",
"nil": "null",
"undefined": "undefined",
"function": "funkcja",
"date": "data",
"file": "plik",
"set": "zbiór",
}
TypeDictionaryPl maps Polish type name translations.
var TypeDictionaryPt = map[string]string{
"nan": "NaN",
"number": "número",
"array": "array",
"slice": "array",
"string": "texto",
"bool": "booleano",
"object": "objeto",
"map": "mapa",
"nil": "nulo",
"undefined": "indefinido",
"function": "função",
"date": "data",
"file": "arquivo",
"set": "conjunto",
}
TypeDictionaryPt maps Portuguese type name translations.
var TypeDictionaryRu = map[string]string{
"nan": "NaN",
"number": "число",
"array": "массив",
"slice": "массив",
"string": "строка",
"bool": "логическое значение",
"object": "объект",
"map": "карта",
"nil": "null",
"undefined": "undefined",
"function": "функция",
"date": "дата",
"file": "файл",
"set": "множество",
}
TypeDictionaryRu maps Russian type name translations.
var TypeDictionarySv = map[string]string{
"nan": "NaN",
"number": "antal",
"array": "lista",
"slice": "lista",
"string": "sträng",
"bool": "boolean",
"object": "objekt",
"map": "karta",
"nil": "null",
"undefined": "odefinierad",
"function": "funktion",
"date": "datum",
"file": "fil",
"set": "mängd",
}
TypeDictionarySv maps Swedish type name translations.
var TypeDictionaryTa = map[string]string{
"nan": "NaN",
"number": "எண்",
"array": "அணி",
"slice": "அணி",
"string": "சரம்",
"bool": "பூலியன்",
"object": "பொருள்",
"map": "வரைபடம்",
"nil": "வெறுமை",
"null": "வெறுமை",
"undefined": "வரையறுக்கப்படாதது",
"function": "செயல்பாடு",
"date": "தேதி",
"file": "கோப்பு",
"set": "தொகுப்பு",
}
TypeDictionaryTa maps Tamil type name translations.
var TypeDictionaryTh = map[string]string{
"nan": "NaN",
"number": "ตัวเลข",
"array": "อาร์เรย์ (Array)",
"slice": "อาร์เรย์ (Array)",
"string": "ข้อความ",
"bool": "บูลีน",
"object": "อ็อบเจกต์",
"map": "แผนที่",
"nil": "ไม่มีค่า (null)",
"undefined": "ไม่ได้กำหนดค่า",
"function": "ฟังก์ชัน",
"date": "วันที่",
"file": "ไฟล์",
"set": "เซต",
}
TypeDictionaryTh maps Thai type name translations.
var TypeDictionaryTr = map[string]string{
"nan": "NaN",
"number": "sayı",
"array": "dizi",
"slice": "dizi",
"string": "metin",
"bool": "mantıksal",
"object": "nesne",
"map": "harita",
"nil": "boş",
"undefined": "tanımsız",
"function": "fonksiyon",
"date": "tarih",
"file": "dosya",
"set": "küme",
}
TypeDictionaryTr maps Turkish type name translations.
var TypeDictionaryUk = map[string]string{
"nan": "NaN",
"number": "число",
"array": "масив",
"slice": "масив",
"string": "рядок",
"bool": "булеве значення",
"object": "об'єкт",
"map": "карта",
"nil": "null",
"undefined": "undefined",
"function": "функція",
"date": "дата",
"file": "файл",
"set": "множина",
}
TypeDictionaryUk maps Ukrainian type name translations.
var TypeDictionaryUr = map[string]string{
"nan": "NaN",
"number": "نمبر",
"array": "آرے",
"slice": "آرے",
"string": "سٹرنگ",
"bool": "بولین",
"object": "آبجیکٹ",
"map": "میپ",
"nil": "نل",
"null": "نل",
"undefined": "غیر متعین",
"function": "فنکشن",
"date": "تاریخ",
"file": "فائل",
"set": "سیٹ",
}
TypeDictionaryUr maps Urdu type name translations.
var TypeDictionaryVi = map[string]string{
"nan": "NaN",
"number": "số",
"array": "mảng",
"slice": "mảng",
"string": "chuỗi",
"bool": "boolean",
"object": "đối tượng",
"map": "bản đồ",
"nil": "null",
"undefined": "không xác định",
"function": "hàm",
"date": "ngày",
"file": "tệp",
"set": "tập hợp",
}
TypeDictionaryVi maps Vietnamese type name translations.
var TypeDictionaryZhTw = map[string]string{
"nan": "NaN",
"number": "數字",
"array": "陣列",
"slice": "陣列",
"string": "字串",
"bool": "布林值",
"object": "物件",
"map": "對應表",
"nil": "null",
"undefined": "undefined",
"function": "函式",
"date": "日期",
"file": "檔案",
"set": "集合",
}
TypeDictionaryZhTw maps Traditional Chinese type name translations.
var TypeNamesHe = map[string]hebrewTypeInfo{
"string": {Label: "מחרוזת", Gender: "f"},
"number": {Label: "מספר", Gender: "m"},
"bool": {Label: "ערך בוליאני", Gender: "m"},
"boolean": {Label: "ערך בוליאני", Gender: "m"},
"bigint": {Label: "BigInt", Gender: "m"},
"date": {Label: "תאריך", Gender: "m"},
"array": {Label: "מערך", Gender: "m"},
"slice": {Label: "מערך", Gender: "m"},
"object": {Label: "אובייקט", Gender: "m"},
"nil": {Label: "ערך ריק (null)", Gender: "m"},
"undefined": {Label: "ערך לא מוגדר (undefined)", Gender: "m"},
"symbol": {Label: "סימבול (Symbol)", Gender: "m"},
"function": {Label: "פונקציה", Gender: "f"},
"map": {Label: "מפה (Map)", Gender: "f"},
"set": {Label: "קבוצה (Set)", Gender: "f"},
"file": {Label: "קובץ", Gender: "m"},
"promise": {Label: "Promise", Gender: "m"},
"NaN": {Label: "NaN", Gender: "m"},
"unknown": {Label: "ערך לא ידוע", Gender: "m"},
"value": {Label: "ערך", Gender: "m"},
}
TypeNamesHe maps Hebrew type names with gender.
Functions ¶
func AvailableLocales ¶ added in v0.6.5
func AvailableLocales() []string
AvailableLocales returns a list of all registered locale identifiers. Useful for UI components that need to display available localization options. Uses slicex for better slice handling.
func FilterUniqueLocales ¶ added in v0.2.0
FilterUniqueLocales removes duplicate locales from a slice Demonstrates slicex.Unique functionality
func FormatMessageAr ¶ added in v0.5.4
func FormatMessageAr(issue core.ZodRawIssue) string
FormatMessageAr formats a single issue using Arabic locale
func FormatMessageBg ¶ added in v0.5.4
func FormatMessageBg(issue core.ZodRawIssue) string
FormatMessageBg formats a single issue using Bulgarian locale
func FormatMessageCs ¶ added in v0.5.4
func FormatMessageCs(issue core.ZodRawIssue) string
FormatMessageCs formats a single issue using Czech locale
func FormatMessageDa ¶ added in v0.5.4
func FormatMessageDa(issue core.ZodRawIssue) string
FormatMessageDa formats a single issue using Danish locale
func FormatMessageDe ¶ added in v0.5.4
func FormatMessageDe(issue core.ZodRawIssue) string
FormatMessageDe formats a single issue using German locale
func FormatMessageEn ¶ added in v0.4.0
func FormatMessageEn(issue core.ZodRawIssue) string
FormatMessageEn formats a single issue using English locale
func FormatMessageEs ¶ added in v0.5.4
func FormatMessageEs(issue core.ZodRawIssue) string
FormatMessageEs formats a single issue using Spanish locale
func FormatMessageFa ¶ added in v0.5.4
func FormatMessageFa(issue core.ZodRawIssue) string
FormatMessageFa formats a single issue using Persian locale
func FormatMessageFi ¶ added in v0.5.4
func FormatMessageFi(issue core.ZodRawIssue) string
FormatMessageFi formats a single issue using Finnish locale
func FormatMessageFr ¶ added in v0.5.4
func FormatMessageFr(issue core.ZodRawIssue) string
FormatMessageFr formats a single issue using French locale
func FormatMessageHe ¶ added in v0.5.4
func FormatMessageHe(issue core.ZodRawIssue) string
FormatMessageHe formats a single issue using Hebrew locale
func FormatMessageHu ¶ added in v0.5.4
func FormatMessageHu(issue core.ZodRawIssue) string
FormatMessageHu formats a single issue using Hungarian locale
func FormatMessageID ¶ added in v0.7.0
func FormatMessageID(issue core.ZodRawIssue) string
FormatMessageID formats a single issue using Indonesian locale
func FormatMessageIt ¶ added in v0.5.4
func FormatMessageIt(issue core.ZodRawIssue) string
FormatMessageIt formats a single issue using Italian locale
func FormatMessageJa ¶ added in v0.5.4
func FormatMessageJa(issue core.ZodRawIssue) string
FormatMessageJa formats a single issue using Japanese locale
func FormatMessageKo ¶ added in v0.5.4
func FormatMessageKo(issue core.ZodRawIssue) string
FormatMessageKo formats a single issue using Korean locale
func FormatMessageMs ¶ added in v0.5.4
func FormatMessageMs(issue core.ZodRawIssue) string
FormatMessageMs formats a single issue using Malay locale
func FormatMessageNl ¶ added in v0.5.4
func FormatMessageNl(issue core.ZodRawIssue) string
FormatMessageNl formats a single issue using Dutch locale
func FormatMessageNo ¶ added in v0.5.4
func FormatMessageNo(issue core.ZodRawIssue) string
FormatMessageNo formats a single issue using Norwegian locale
func FormatMessagePl ¶ added in v0.5.4
func FormatMessagePl(issue core.ZodRawIssue) string
FormatMessagePl formats a single issue using Polish locale
func FormatMessagePt ¶ added in v0.5.4
func FormatMessagePt(issue core.ZodRawIssue) string
FormatMessagePt formats a single issue using Portuguese locale
func FormatMessageRu ¶ added in v0.5.4
func FormatMessageRu(issue core.ZodRawIssue) string
FormatMessageRu formats a single issue using Russian locale
func FormatMessageSv ¶ added in v0.5.4
func FormatMessageSv(issue core.ZodRawIssue) string
FormatMessageSv formats a single issue using Swedish locale
func FormatMessageTa ¶ added in v0.5.4
func FormatMessageTa(issue core.ZodRawIssue) string
FormatMessageTa formats a single issue using Tamil locale
func FormatMessageTh ¶ added in v0.5.4
func FormatMessageTh(issue core.ZodRawIssue) string
FormatMessageTh formats a single issue using Thai locale
func FormatMessageTr ¶ added in v0.5.4
func FormatMessageTr(issue core.ZodRawIssue) string
FormatMessageTr formats a single issue using Turkish locale
func FormatMessageUk ¶ added in v0.5.4
func FormatMessageUk(issue core.ZodRawIssue) string
FormatMessageUk formats a single issue using Ukrainian locale
func FormatMessageUr ¶ added in v0.5.4
func FormatMessageUr(issue core.ZodRawIssue) string
FormatMessageUr formats a single issue using Urdu locale
func FormatMessageVi ¶ added in v0.5.4
func FormatMessageVi(issue core.ZodRawIssue) string
FormatMessageVi formats a single issue using Vietnamese locale
func FormatMessageZh ¶ added in v0.4.0
func FormatMessageZh(issue core.ZodRawIssue) string
FormatMessageZh formats a single issue using Chinese locale
func FormatMessageZhTw ¶ added in v0.5.4
func FormatMessageZhTw(issue core.ZodRawIssue) string
FormatMessageZhTw formats a single issue using Traditional Chinese locale
func JoinLocalizedMessages ¶ added in v0.2.0
func JoinLocalizedMessages(issues []core.ZodRawIssue, locale string, separator string) (string, error)
JoinLocalizedMessages joins multiple localized messages with a separator. Utilizes slicex.Join for consistent formatting.
func LocaleFormatter ¶ added in v0.2.0
func LocaleFormatter(locale string) func(core.ZodRawIssue) string
LocaleFormatter returns a formatter function for the given locale. Falls back to English if the locale is not found, ensuring robust operation.
func LocalizedError ¶ added in v0.6.5
func LocalizedError(issue core.ZodRawIssue, locale string) string
LocalizedError returns a localized error message for the given issue and locale. This is a convenience function for backward compatibility and simple usage.
func LocalizedErrors ¶ added in v0.6.5
func LocalizedErrors(issues []core.ZodRawIssue, locale string) ([]string, error)
LocalizedErrors returns localized error messages for multiple issues. Uses slicex for efficient slice processing.
func RegisterLocale ¶ added in v0.2.0
func RegisterLocale(locale string, formatFunc func(core.ZodRawIssue) string)
RegisterLocale adds a new locale to the default locales map Allows runtime registration of additional locales and custom formatters
func ValidateLocaleList ¶ added in v0.2.0
ValidateLocaleList checks if all locales in a slice are supported Returns valid locales and invalid ones separately using slicex.Filter
Types ¶
type LocaleErrorMap ¶ added in v0.4.0
type LocaleErrorMap map[string]func(core.ZodRawIssue) string
LocaleErrorMap maps locale names to their corresponding formatter functions Following TypeScript Zod v4's functional approach instead of struct-based patterns